@@ -1,12 +1,14 @@
 import html.parser
 import re
-from typing import Union
+from typing import Optional, Union
 
 from easy_scraper import entity
 
 
 class HTMLParser(html.parser.HTMLParser):
-    def text(self, data: str) -> Union[entity.PlainText, entity.Pattern]:
+    def text(self, data: Optional[str]) -> entity.Html:
+        if data is None:
+            return entity.Empty()
         data = data.strip()
         if self.is_pattern:
             match = re.match(r"{{\s*(\w*)\s*}}", data)
@@ -23,6 +25,7 @@ class HTMLParser(html.parser.HTMLParser):
         return root
 
     def handle_starttag(self, tag, attrs):
+        print(attrs)
         attrs = {name: self.text(data) for name, data in attrs}
         child = entity.Elem(tag, attrs, [], self.cur)
         self.cur.children.append(child)
